@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: pandoc-citeproc
-version: 0.9.1.1
-id: pandoc-citeproc-0.9.1.1-5748d0995df6dc75a64f38e63a91d870
-key: pando_JW9rI2qTRiW07pRFtMLBgI
+version: 0.9
+id: pandoc-citeproc-0.9-82d758a0aade0504e63eea3491cf7af5
+key: pando_478PLhXnevFJp0qZzcdIo3
 license: BSD3
 maintainer: jgm@berkeley.edu
 homepage: https://github.com/jgm/pandoc-citeproc
@@ -39,35 +39,35 @@ exposed-modules:
     Text.CSL.Output.Pandoc Text.CSL.Output.Plain Text.CSL.Data
 hidden-modules: Text.CSL.Util Prelude Paths_pandoc_citeproc
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
-library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9.1.1
+import-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9
+library-dirs: /usr/lib/ghc-7.10.3/site-local/pandoc-citeproc-0.9
 data-dir: /usr/share/pandoc-citeproc
-hs-libraries: HSpandoc-citeproc-0.9.1.1-JW9rI2qTRiW07pRFtMLBgI
+hs-libraries: HSpandoc-citeproc-0.9-478PLhXnevFJp0qZzcdIo3
 depends:
-    aeson-0.11.2.0-296caa0c9ed52dbc363a5964bf5cee68
+    aeson-0.11.1.1-0413068b3d94ca1008e286bfe7fa084f
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
     containers-0.5.6.2-169e53288f333dd2f0207994fd53822f
-    data-default-0.6.0-4c4f075845d560f7a31d444f67905db9
+    data-default-0.5.3-a34fab0e414a3e31b9dccb1774520fca
     directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
     filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
     hs-bibutils-5.5-91f8c150a94b021e3f1d7580075e1ca0
     mtl-2.2.1-c516313407bc17046965067cb7cbb6a0
     old-locale-1.0.0.7-5aedb410aa2e5fddd3c57e9b4de1f46a
-    pandoc-1.17.0.3-385c8e8a07c6129d5c295aa0dcb411ba
-    pandoc-types-1.16.1-30bcf2ba2a8f2fe5e0ad6c109c33aa1e
-    parsec-3.1.11-2df9dc070a05b018377712731c5dde62
+    pandoc-1.16.0.2-1e3210a759893e8cb19c047605eb93fb
+    pandoc-types-1.16.1-4cd1533070797f7596c108f3982c26c4
+    parsec-3.1.9-e73195cf6af19ee9d1587f67fa792c42
     setenv-0.1.1.3-4d70f2e61b1bd0645017164a0ca26ee9
-    split-0.2.3.1-720861915f5bd1738e9c1363195cfb8f
+    split-0.2.3-1755fd7a4bff52537a62f0056f73dfbc
     syb-0.6-56a5944f55f7a9d47e7b770375c0e1ae
-    tagsoup-0.13.10-e0607642a7a600be1f9d9bab46fd617e
-    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
-    text-icu-0.7.0.1-5ca732f0eac6589810e9e4239ad6c2ab
+    tagsoup-0.13.8-ae67a6a9bc7b71798dd8f975b70085f0
+    text-1.2.2.0-2f82ea4adfdd656d9a8840ad2ee17cc0
+    text-icu-0.7.0.1-6e6eefd2e8d16edc12cf2661f6f4ef14
     time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
-    unordered-containers-0.2.7.0-d91279dcd5fa13d7f88095dc08e2fda6
+    unordered-containers-0.2.7.0-03f1d2fb96e30aca19bb1467e9476c22
     vector-0.11.0.0-711d35c4a6ac1ea2e529dc3ee3328963
-    xml-conduit-1.3.5-b0d7925ea0f1a62fe18b3cdd25dd3416
-    yaml-0.8.17.1-e4e3d8aa5aa8eb9fbd84f744946960bc
+    xml-conduit-1.3.4-e268a8d251308faa5ddb6ec5be7cd100
+    yaml-0.8.16-dde1f04caad6e58716b323c82d57d5b4
 haddock-interfaces: /usr/share/doc/pandoc-citeproc/html/pandoc-citeproc.haddock
 haddock-html: /usr/share/doc/pandoc-citeproc/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
